**pyseisdl**
======

## Description

**pyseisdl** is a python package for different dictionary learning methods and their applications in seismology. DL has a variety of applications in seismology, including but not limited to seismic denoising, seismic reconstruction, seismic diffraction separation, constrained LSRTM, constrained FWI, etc.

## Reference
    Chen, Y. (2020). Fast dictionary learning for noise attenuation of multidimensional seismic data. Geophysical Journal International, 222(3), 1717-1727.
    
    Wang, H., Chen, W., Zhang, Q., Liu, X., Zu, S., & Chen, Y. (2020). Fast dictionary learning for high-dimensional seismic reconstruction. IEEE Transactions on Geoscience and Remote Sensing, 59(8), 7098-7108.
    
BibTeX:

	@article{chen2020sgk,
	  title={Fast dictionary learning for noise attenuation of multidimensional seismic data},
	  author={Yangkang Chen},
	  journal={Geophysical Journal International},
	  volume={222},
	  number={3},
	  issue={3},
	  pages={1717-1727},
	  year={2020}
	}

	@article{wang2021sgk,
	  title={Fast dictionary learning for high-dimensional seismic reconstruction},
	  author={Hang Wang and Wei Chen and Quan Zhang and Xingye Liu and Shaohuan Zu and Yangkang Chen},
	  journal={IEEE Transactions on Geoscience and Remote Sensing},
	  volume={59},
	  number={8},
	  issue={8},
	  pages={7098-7108},
	  doi={10.1109/TGRS.2020.3030740},
	  year={2021}
	}

-----------
## Copyright
    Initial version: Yangkang Chen (chenyk2016@gmail.com), 2021-2022
	Later version: pyseisdl developing team, 2022-present
-----------

## License
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)   

-----------

## Install
Using the latest version

    git clone https://github.com/chenyk1990/pyseisdl
    cd pyseisdl
    pip install -v -e .
or using Pypi

    pip install pyseisdl

-----------
## Examples
    The "demo" directory contains all runable scripts to demonstrate different applications of pyseisdl. 

-----------
## Gallery
The gallery figures of the pydrr package can be found at
    https://github.com/chenyk1990/gallery/tree/main/pyseisdl
Each figure in the gallery directory corresponds to a DEMO script in the "demo" directory with the exactly the same file name.

-----------
## Dependence Packages
* scipy 
* numpy 
* matplotlib

-----------
## Development
    The development team welcomes voluntary contributions from any open-source enthusiast. 
    If you want to make contribution to this project, feel free to contact the development team. 

-----------
## Contact
    Regarding any questions, bugs, developments, collaborations, please contact  
    Yangkang Chen
    chenyk2016@gmail.com

-----------


